/*
 * Copyright (c) 2006
 *
 * written by Simon Barrick
 * simon@fourthwall.ndo.co.uk
 *
 * PointSlide SOP
 */


#ifndef __SOP_PointSlide_h__
#define __SOP_PointSlide_h__

#include <SOP/SOP_Node.h>
#include <CH/CH_LocalVariable.h>

class SOP_PointSlide : public SOP_Node
{
public:
       SOP_PointSlide(OP_Network *net, const char *name, OP_Operator *op);
    virtual ~SOP_PointSlide();

    static PRM_Template    myTemplateList[];
    static CH_LocalVariable       myVariables[];

    static OP_Node    *myConstructor(OP_Network*, const char *,
                  OP_Operator *);

    // This method is created so that it can be called by handles.  It only
    // cooks the input group of this SOP.  The geometry in this group is
    // the only geometry manipulated by this SOP.
    virtual OP_ERROR     cookInputGroups(OP_Context &context, int alone = 0);

protected:

    // Method to cook geometry for the SOP
    virtual OP_ERROR     cookMySop(OP_Context &context);
    virtual unsigned      disableParms();

    virtual const char    *inputLabel(unsigned int) const;

    // You only have to write this function if you have local variables
    virtual float    getVariableValue(int index, int thread);


private:

    int   TYPE()             { return evalInt("type", 0, 0); }
    int   REV()              { return evalInt("reverse", 0, 0); }
    int   SPLIT()            { return evalInt("split", 0, 0); }
    float DIST(float t)      { return evalFloat("dist", 0, t); }
    int   ITER(float t)      { return evalInt("iterations", 0, t); }
    float RADIUS(float t)    { return evalFloat("radius", 0, t); }
    int   CLAMP()            { return evalInt("clamp", 0, 0); }

    // This variable is used together with the call to the "checkInputChanged"
    // routine to notify the handles (if any) if the input has changed.
    GU_DetailGroupPair   myDetailGroupPair;

    // This is the group of geometry to be manipulated by this SOP and cooked
    // by the method "cookInputGroups".
    const GB_EdgeGroup *myGroup;
    GB_EdgeGroup *myEdgeGroup;

    void  getGroups(UT_String &str) { evalString(str, 0, 0, 0); }

    int splitVertices(GU_Detail *gdp);

    bool edgegroup;
    bool reverse;

    int myCurrEdge;
    int myCurrPoint;
    int myCurrEndPoint;

};

#endif
